// *********************************************************************
//                    D/A converter controled via RF
//                            Demo example 
// *********************************************************************
//
// Intended for:
//   HW: - TR-76G and appropriate user HW
//
//   OS: - v4.06G
//
// Description:
//   - this example controls DAC output via received RF commands
//   - pin Q10 (RA2) is used as DAC output. 
//     OS uses this pin for red LED control, so do not use OS LEDR functions.
//   - use example E03-TR as a transmiter 
//   - use IQRF IDE 4.47 or higher - Terminal (Use Numbers must be checked, see IQRF IDE Help)
//   - import prepared macros file DAC_macros.iqrfmcr to the IQRF IDE
//
//   Commands to be sent from the transmiter: 'D'<DAC output>
//      <DAC output>: 0 ~ 0 V, ..., 16 ~ 1.5 V, ..., 31 ~ 2.9 V
//      For more exact calculation see MCU datasheet.
//      (e.g. "D#016" -> DAC output = 1.5 V)
//
// ---------------------------------------------------------------------
// Online IQRF OS Reference Guide: https://doc.iqrf.org/IQRF-OS-Reference-guide
//
// Copyright (c) IQRF Tech s.r.o.
//
// File:    TR_DAC.c
// Version: v3.00                                   Revision: 21/06/2021
//
// Revision history:
//   v3.00: 21/06/2021  First release for TR-7xG.
//
// *********************************************************************
// Default IQRF include (modify the path according to your setup)
#include "IQRF.h"

// *********************************************************************
#define RX_FILTER               5

// *********************************************************************
void initDAC();

// *********************************************************************

void APPLICATION()
{
    setLEDR();
    waitDelay(50);                          // Startup indication
    stopLEDR();
    initDAC();
    setRFmode(_WPE | _RX_STD | _TX_STD);
    _checkRFcfg_PQT = 1;                    // Enable preamble quality test
    toutRF = 1;                             // Wait Packed End active so the toutRF can be set to minimum
    
    while (1)
    {   
        if (checkRF(RX_FILTER))
        {
            if (RFRXpacket())               
            {
                if (bufferRF[0] == 'D')
                {
                    pulseLEDG();
                    DAC1CON1 = bufferRF[1]; // DAC output control (pin RA2)
                }
            }
        }
    }
}
// *********************************************************************

void initDAC()              
{
    DACMD = 0;                      // Enable DAC module
    DAC1CON0 = 0b10100000;          // DAC on, output 1 enabled, from VDD to VSS
    DAC1CON1 = 16;                  // Default voltage output. 16 means 1.5 V.
}
// *********************************************************************
